@@ -53,8 +53,8 @@ get.l <- function(
            length.out = n)
   
   ## set class of l
-  class(l) <- "EMMAgeo_l"
+  class(l)[1] <- "EMMAgeo_l"
   
   ## return output  
   return(l)
-}
\ No newline at end of file
+}
