@@ -166,8 +166,8 @@ get.q <- function(X,
   q <- cbind(na.omit(object = q))
   
   ## set class
-  class(q) <- "EMMAgeo_q"
+  class(q)[1] <- "EMMAgeo_q"
   
   ## return result
   return(q)
-}
\ No newline at end of file
+}
