@@ -62,33 +62,35 @@
 #' @keywords EMMA
 #' @examples
 #' 
-#' ## Not run because of long computation time, compact protocol
+#' \dontrun{
 #' 
 #' ## load example data set
-#' # data(example_X)
+#' data(example_X)
 #' 
 #' ## get weight transformation limit vector
-#' # l <- get.l(X = X)
+#' l <- get.l(X = X)
 #' 
 #' ## get minimum and maximum number of end-members
-#' # q <- get.q(X = X, l = l)
+#' q <- get.q(X = X, l = l)
 #' 
 #' ## get all potential model scenarios
-#' # EM_pot <- model.EM(X = X, q = q, plot = TRUE)
+#' EM_pot <- model.EM(X = X, q = q, plot = TRUE)
 #' 
 #' ## define end-member mode class limits
-#' # limits <- cbind(c(61, 74, 95, 102), 
-#' #                 c(64, 76, 100, 105))
+#' limits <- cbind(c(61, 74, 95, 102), 
+#'                 c(64, 76, 100, 105))
 #' 
 #' ## get robust end-members in the default way, with plot output
-#' # rem <- robust.EM(em = EM_pot,
-#' #                  limits = limits,
-#' #                  plot = TRUE)
+#' rem <- robust.EM(em = EM_pot,
+#'                  limits = limits,
+#'                  plot = TRUE)
 #'                     
 #' ## get robust end-members by only modelling uncertainty in loadings
-#' # robust_EM <- robust.EM(em = EM_pot, 
-#' # limits = limits, 
-#' # plot = TRUE)
+#' robust_EM <- robust.EM(em = EM_pot, 
+#'                        limits = limits, 
+#'                        plot = TRUE)
+#' 
+#' }
 #'                     
 #' @export robust.EM
 robust.EM <- function(
@@ -188,7 +190,7 @@ robust.EM <- function(
     mc_n <- 10 * nrow(Vqn_average) * length(em$l_in)
   }
   
-  if(class(l) == "try-error") {
+  if(class(l)[1] == "try-error") {
     
     stop("No end-members found that match limit definitions!")
   }
@@ -439,6 +441,7 @@ robust.EM <- function(
   return(list(loadings = robust_loadings$Vqsn,
               scores = list(mean = robust_scores$mean,
                             sd = robust_scores$sd),
+              Vqn = robust_loadings$Vqn,
               Xm = robust_scores$Xm,
               modes = robust_scores$modes,
               Mqs.var = robust_scores$Mqs.var,
